# mel

Machine learning toolkit for tensorflow and pytorch.

See [examples](#examples).

## Contact

- Twitter: [@theshawwn](https://twitter.com/theshawwn)
- HN: [sillysaurusx](https://news.ycombinator.com/item?id=23346972)
- Discord: [ML Community](#ml-community)
- Patreon: [thank you!](https://www.shawwn.com/thanks)

## Quickstart

```
# Install mel
pip3 install -U mel
```

## Examples

TODO

## ML Community

If you're an ML enthusiast, join our [TPU Podcast Discord Server](https://discordapp.com/invite/x52Xz3y).
There are now ~400 members, with ~60 online at any given time:

![image](https://user-images.githubusercontent.com/59632/84269906-bc7d2080-aade-11ea-8b4e-f78412855d43.png)

There are a variety of interesting channels:

- `#papers` for pointing out interesting research papers
- `#research` for discussing ML research
- `#show` and `#samples` for showing off your work
- `#hardware` for hardware enthusiasts
- `#ideas` for brainstorming
- `#tensorflow` and `#pytorch`
- `#cats`, `#doggos`, and of course `#memes`
- A "bot zone" for interacting with our discord bots, such as using
  `!waifu red_hair blue_eyes` to generate an anime character using
  stylegan:
![image](https://user-images.githubusercontent.com/59632/84270613-cfdcbb80-aadf-11ea-9762-83b0c84d4cc6.png)
- Quite a few more.

## Support

*If you found this library heplful, consider [joining my patreon](https://www.shawwn.com/thanks).*
